@@ -13,9 +13,7 @@
 # under the License.
 
 import time
-
-import six.moves.urllib.parse as urlparse
-from six import text_type
+from urllib import parse as urlparse
 
 from monasca_tempest_tests.tests.api import base
 from monasca_tempest_tests.tests.api import constants
@@ -319,11 +317,11 @@ class TestNotificationMethods(base.BaseMonascaTest):
         element = elements[0]
         self.assertTrue(set(['id', 'links', 'name', 'type', 'address', 'period']) ==
                         set(element))
-        self.assertTrue(type(element['id']) is text_type)
+        self.assertTrue(type(element['id']) is str)
         self.assertTrue(type(element['links']) is list)
-        self.assertTrue(type(element['name']) is text_type)
-        self.assertTrue(type(element['type']) is text_type)
-        self.assertTrue(type(element['address']) is text_type)
+        self.assertTrue(type(element['name']) is str)
+        self.assertTrue(type(element['type']) is str)
+        self.assertTrue(type(element['address']) is str)
 
         resp, response_body = self.monasca_client.\
             delete_notification_method(id)
